import { Injectable } from '@nestjs/common';
import { DateTime, TimeZone } from 'timezonecomplete';
import { TimeConverterPort } from '../core/application/ports/time-converter.port';

@Injectable()
export class TimeConverter implements TimeConverterPort {
  localDateTimeToUtc = (
    date: string,
    time: string,
    timezone: string,
    dst?: boolean,
  ): Date => {
    try {
      if (!date || !time || !timezone) throw new Error();
      return new Date(
        new DateTime(`${date}T${time}`, TimeZone.zone(timezone, dst))
          .convert(TimeZone.zone('UTC'))
          .toIsoString(),
      );
    } catch (e) {
      return undefined;
    }
  };

  utcDatetimeToLocalTime = (isoString: string, timezone: string): string => {
    try {
      return new DateTime(isoString)
        .convert(TimeZone.zone(timezone))
        .toString()
        .split('T')[1]
        .substring(0, 5);
    } catch (e) {
      return undefined;
    }
  };
}
